@@ -13,7 +13,7 @@ function main (cxt) {
 // : : CREATE ] DOES> doLIST ;
     def(':', function () {
         var w = this.io.word('\\s');
-        this.state = 1;
+        this.setState(1);
         this.cfs = [];
         this.lastw = w;
         this.pos = [];
@@ -25,18 +25,18 @@ function main (cxt) {
 // : ; next [ ; IMMEDIATE
 // : ; POSTPONE EXIT  REVEAL POSTPONE [ ; IMMEDIATE
     def(';', function () {
-        this.state = 0;
+        this.setState(0);
         def(this.lastw, this.ast, this);
     }, cxt, { immediate: true });
 
 // : [ -1 STATE ! ; IMMEDIATE
     def('[', function () {
-        this.state = 0;
+        this.setState(0);
     }, cxt, { immediate: true });
 
 // : ] 0 STATE ! ;
     def(']', function () {
-        this.state = 1;
+        this.setState(1);
     }, cxt);
 
 // 6.1.2250 STATE (CORE)
@@ -49,7 +49,7 @@ function main (cxt) {
 // Note: A program shall not directly alter the contents of STATE.
 
     def('state', function () {
-        this.dpush(this.state); // TODO should be real state memory cell
+        this.dpush(this.stateAddr()); // TODO should be real state memory cell
     }, cxt);
 
 
@@ -66,7 +66,11 @@ function main (cxt) {
         var w = this.io.word('\\s');
         var wordLink = this.O[w.toLowerCase()];
         if (wordLink) {
-           this.pos.push(ast.callword(wordLink.index));
+            if (wordLink.immediate) {
+                this.pos.push(ast.callword(wordLink.index));
+            } else {
+                this.pos.push(ast.postpone(wordLink.index));
+            }
         } else {
             cxt.log('word: ' + w + ' is not defined');
             throw new Error;
@@ -525,9 +529,14 @@ function main (cxt) {
 //      ccc. A program shall not alter the returned string.
     def('s"', function () {
         var w = this.io.parse('"');
-        // TODO copy to the memory
-        this.pos.push(ast.dpush(0)); // TODO addr
-        this.pos.push(ast.dpush(w.length));
+        var i, ilen, here;
+        here = this.here;
+        for (i = 0, ilen = w.length; i < ilen; i++) {
+            this.MEMi8[here + i] = w.charCodeAt(i);
+        }
+        this.here += ilen;
+        this.pos.push(ast.dpush(here)); // TODO addr
+        this.pos.push(ast.dpush(ilen));
     }, cxt, { immediate: true });
 
 // : DO POSTPONE 2>R HERE ; IMMEDIATE
@@ -951,8 +960,8 @@ function main (cxt) {
 
     def('+loop', function () {
         this.pos.push({
-            type: Syntax.ExpressionStatement,
-            expression: {
+            type: Syntax.IfStatement,
+            test: {
                 type: Syntax.CallExpression,
                 callee: {
                     type: Syntax.MemberExpression,
@@ -962,73 +971,18 @@ function main (cxt) {
                     },
                     property: {
                         type: Syntax.Identifier,
-                        name: 'rpush'
+                        name: 'plusloop'
                     }
                 },
-                arguments: [
-                    {
-                        type: Syntax.BinaryExpression,
-                        operator: '+',
-                        left: ast.rpop(),
-                        right: ast.dpop()
-                    }
-                ]
-            }
+                arguments: []
+            },
+            consequent: {
+                type: Syntax.BreakStatement,
+                label: null
+            },
+            alternate: null
         });
         this.pos = this.cfs.pop();
-
-        this.pos[this.pos.length - 1].body.test = {
-            type: Syntax.BinaryExpression,
-            operator: '!==',
-            left: {
-                type: Syntax.BinaryExpression,
-                operator: '>>>',
-                left: {
-                    type: Syntax.CallExpression,
-                    callee: {
-                        type: Syntax.MemberExpression,
-                        computed: false,
-                        object: {
-                            type: Syntax.ThisExpression
-                        },
-                        property: {
-                            type: Syntax.Identifier,
-                            name: 'rtop'
-                        }
-                    },
-                    arguments: []
-                },
-                right: {
-                    type: Syntax.Literal,
-                    value: 0,
-                    raw: '0'
-                }
-            },
-            right: {
-                type: Syntax.BinaryExpression,
-                operator: '>>>',
-                left: {
-                    type: Syntax.CallExpression,
-                    callee: {
-                        type: Syntax.MemberExpression,
-                        computed: false,
-                        object: {
-                            type: Syntax.ThisExpression
-                        },
-                        property: {
-                            type: Syntax.Identifier,
-                            name: 'rnext'
-                        }
-                    },
-                    arguments: []
-                },
-                right: {
-                    type: Syntax.Literal,
-                    value: 0,
-                    raw: '0'
-                }
-            }
-        };
         this.pos.push({
             type: Syntax.ExpressionStatement,
             expression: ast.rpop()
@@ -1168,8 +1122,12 @@ function main (cxt) {
     }, cxt, { immediate: true });
 
     def('>body', function () {
-        this.dpop();
-        this.dpush(this.O[this.L].body);
+        var xt = this.dpop();
+        var word = this.L[xt];
+        var name = word.name;
+        var obj = this.O[name];
+        var dfa = obj.dfa;
+        this.dpush(dfa);
     }, cxt, { immediate: true });
 
 
@@ -1187,6 +1145,75 @@ function main (cxt) {
         this.pos.push(ast.callword(index));
     }, cxt, { immediate: true });
 
+    // 6.1.0190 ."
+        def('."', function () {
+            var w = this.io.parse('"');
+            this.pos.push({
+                type: Syntax.ExpressionStatement,
+                expression: {
+                    type: Syntax.CallExpression,
+                    callee: {
+                        type: Syntax.MemberExpression,
+                        computed: false,
+                        object: {
+                            type: Syntax.ThisExpression
+                        },
+                        property: {
+                            type: Syntax.Identifier,
+                            name: 'log'
+                        }
+                    },
+                    arguments: [
+                        {
+                            type: Syntax.Literal,
+                            value: w,
+                            raw: w
+                        }
+                    ]
+                }
+            });
+        }, cxt, { immediate: true });
+
+// 6.1.1250 DOES>
+    def('does>', function () {
+        var oldpos = this.pos;
+        this.pos = [];
+        oldpos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'does'
+                    }
+                },
+                arguments: [
+                    {
+                        type: Syntax.FunctionExpression,
+                        id: null,
+                        params: [],
+                        defaults: [],
+                        body: {
+                            type: Syntax.BlockStatement,
+                            body: this.pos
+                        },
+                        generator: false,
+                        expression: false
+                    },
+                    {
+                        type: Syntax.ThisExpression
+                    }
+                ]
+            }
+        });
+    }, cxt, { immediate: true });
+
 }
 
 module.exports = main;
