@@ -17,10 +17,12 @@ function main (cxt) {
 // CREATE
     def('create', function () {
         var w = this.io.word('\\s');
-        var here = this.here;
-        def(w, function () {
-            this.dpush(here);
-        }, this, {body: here});
+        def(
+            w,
+            'function () { this.dpush(' + this.here + '); }',
+            this,
+            {dfa: this.here}
+        );
     }, cxt);
 
 // CODE
@@ -40,20 +42,24 @@ def('end-code', function () {
 // : VARIABLE CREATE 0 , ;
     def('variable', function () {
         var w = this.io.word('\\s');
-        var here = this.here;
+        def(
+            w,
+            'function () { this.dpush(' + this.here + '); }',
+            this,
+            {dfa: this.here}
+        );
         this.here += 4;
-        def(w, function () {
-            this.dpush(here);
-        }, this);
     }, cxt);
 
 // : CONSTANT CREATE , DOES> @ ;
     def('constant', function () {
         var w = this.io.word('\\s');
         var t = this.dpop();
-        def(w, function () {
-            this.dpush(t);
-        }, this);
+        def(
+            w,
+            'function () { this.dpush(' + t + '); }',
+            this
+        );
     }, cxt);
 
 /*
@@ -114,7 +120,7 @@ def('end-code', function () {
         }
     }, cxt);
 
-// EXECUTE
+// 6.1.1370 EXECUTE
     def('execute', function () {
         var xt = this.dpop();
         this[xt].call(this);
