@@ -3,6 +3,7 @@
 var stream = require('stream'),
     stack = require('./stack'),
     core = require('./core'),
+    does = require('./does'),
     memory = require('./memory'),
     interpret = require('./interpret'),
     create = require('./create'),
@@ -17,12 +18,13 @@ function forth () {
         s: stream.Duplex(),
         pkg: pkg,
         L: [],
-        O: {}
+        O: {},
+        does: does
     };
-    interpret(v);
     stack(v);
-    core(v);
     memory(v);
+    interpret(v);
+    core(v);
     create(v);
     cfg(v);
     return v;
